package VMOMI::DrsInjectorWorkloadCorrelationState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
